<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  68571 => 'Bluesky',
  68572 => 'Digicel',
  68573 => 'Digicel',
  68575 => 'Bluesky',
  68576 => 'Bluesky',
  68577 => 'Digicel',
  68583 => 'Digicel',
  68584 => 'Digicel',
  68585 => 'Digicel',
  68586 => 'Digicel',
  68587 => 'Digicel',
);
