OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Adicionado à lista de servidores confiáveis",
    "Server is already in the list of trusted servers." : "Servidor já pertence à lista de servidores confiáveis.",
    "No server to federate with found" : "Nenhum servidor federado encontrado",
    "Could not add server" : "Não foi possível adicionar servidor",
    "Trusted servers" : "Servidores confiáveis",
    "Federation" : "Federação",
    "Federation allows you to connect with other trusted servers to exchange the user directory." : "Federação permite-o conectar-se a outros servidores confiáveis para troca de diretoria de utilizador.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing." : "Federação permite-o conectar-se a outros servidores confiáveis para trocar a diretoria de utilizador.  Por exemplo, isto será usado para completar automaticamente utilizadores externos para partilhada federada.",
    "+ Add trusted server" : "+ Adicionar servidor confiável",
    "Trusted server" : "Servidor confiável",
    "Add" : "Adicionar"
},
"nplurals=2; plural=(n != 1);");
